/*   -*- buffer-read-only: t -*- vi: set ro:
 *
 *  DO NOT EDIT THIS FILE   (ocsptool-args.c)
 *
 *  It has been AutoGen-ed
 *  From the definitions    /usr/src/ports/gnutls/gnutls-3.6.9-1.i686/src/gnutls-3.6.9/src/ocsptool-args.def
 *  and the template file   options
 *
 * Generated from AutoOpts 42:1:17 templates.
 *
 *  AutoOpts is a copyrighted work.  This source file is not encumbered
 *  by AutoOpts licensing, but is provided under the licensing terms chosen
 *  by the ocsptool author or copyright holder.  AutoOpts is
 *  licensed under the terms of the LGPL.  The redistributable library
 *  (``libopts'') is licensed under the terms of either the LGPL or, at the
 *  users discretion, the BSD license.  See the AutoOpts and/or libopts sources
 *  for details.
 *
 * The ocsptool program is copyrighted and licensed
 * under the following terms:
 *
 *  Copyright (C) 2000-2019 Free Software Foundation, and others, all rights reserved.
 *  This is free software. It is licensed for use, modification and
 *  redistribution under the terms of the GNU General Public License,
 *  version 3 or later <http://gnu.org/licenses/gpl.html>
 *
 *  ocsptool is free software: you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  ocsptool is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *  See the GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __doxygen__
#define OPTION_CODE_COMPILE 1
#include "ocsptool-args.h"
#include <sys/types.h>
#include <sys/stat.h>

#include <errno.h>
#include <fcntl.h>
#include <limits.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#ifdef  __cplusplus
extern "C" {
#endif
extern FILE * option_usage_fp;
#define zCopyright      (ocsptool_opt_strs+0)
#define zLicenseDescrip (ocsptool_opt_strs+283)


#ifndef NULL
#  define NULL 0
#endif

/**
 *  static const strings for ocsptool options
 */
static char const ocsptool_opt_strs[2758] =
/*     0 */ "ocsptool 3.6.9\n"
            "Copyright (C) 2000-2019 Free Software Foundation, and others, all rights reserved.\n"
            "This is free software. It is licensed for use, modification and\n"
            "redistribution under the terms of the GNU General Public License,\n"
            "version 3 or later <http://gnu.org/licenses/gpl.html>\n\0"
/*   283 */ "ocsptool is free software: you can redistribute it and/or modify it under\n"
            "the terms of the GNU General Public License as published by the Free\n"
            "Software Foundation, either version 3 of the License, or (at your option)\n"
            "any later version.\n\n"
            "ocsptool is distributed in the hope that it will be useful, but WITHOUT ANY\n"
            "WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS\n"
            "FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more\n"
            "details.\n\n"
            "You should have received a copy of the GNU General Public License along\n"
            "with this program.  If not, see <http://www.gnu.org/licenses/>.\n\0"
/*   888 */ "Enable debugging\0"
/*   905 */ "DEBUG\0"
/*   911 */ "debug\0"
/*   917 */ "More verbose output\0"
/*   937 */ "VERBOSE\0"
/*   945 */ "verbose\0"
/*   953 */ "Input file\0"
/*   964 */ "INFILE\0"
/*   971 */ "infile\0"
/*   978 */ "Output file\0"
/*   990 */ "OUTFILE\0"
/*   998 */ "outfile\0"
/*  1006 */ "Ask an OCSP/HTTP server on a certificate validity\0"
/*  1056 */ "ASK\0"
/*  1060 */ "ask\0"
/*  1064 */ "Verify response\0"
/*  1080 */ "VERIFY_RESPONSE\0"
/*  1096 */ "verify-response\0"
/*  1112 */ "Print information on a OCSP request\0"
/*  1148 */ "REQUEST_INFO\0"
/*  1161 */ "request-info\0"
/*  1174 */ "Print information on a OCSP response\0"
/*  1211 */ "RESPONSE_INFO\0"
/*  1225 */ "response-info\0"
/*  1239 */ "Generates an OCSP request\0"
/*  1265 */ "GENERATE_REQUEST\0"
/*  1282 */ "generate-request\0"
/*  1299 */ "Use (or not) a nonce to OCSP request\0"
/*  1336 */ "NONCE\0"
/*  1342 */ "no-nonce\0"
/*  1351 */ "no\0"
/*  1354 */ "Reads a set of certificates forming a chain from file\0"
/*  1408 */ "LOAD_CHAIN\0"
/*  1419 */ "load-chain\0"
/*  1430 */ "Reads issuer's certificate from file\0"
/*  1467 */ "LOAD_ISSUER\0"
/*  1479 */ "load-issuer\0"
/*  1491 */ "Reads the certificate to check from file\0"
/*  1532 */ "LOAD_CERT\0"
/*  1542 */ "load-cert\0"
/*  1552 */ "Read OCSP trust anchors from file\0"
/*  1586 */ "LOAD_TRUST\0"
/*  1597 */ "load-trust\0"
/*  1608 */ "Reads the OCSP response signer from file\0"
/*  1649 */ "LOAD_SIGNER\0"
/*  1661 */ "load-signer\0"
/*  1673 */ "Use DER format for input certificates and private keys\0"
/*  1728 */ "INDER\0"
/*  1734 */ "no-inder\0"
/*  1743 */ "Use DER format for output of responses (this is the default)\0"
/*  1804 */ "OUTDER\0"
/*  1811 */ "outder\0"
/*  1818 */ "Use PEM format for output of responses\0"
/*  1857 */ "OUTPEM\0"
/*  1864 */ "outpem\0"
/*  1871 */ "Reads the DER encoded OCSP request from file\0"
/*  1916 */ "LOAD_REQUEST\0"
/*  1929 */ "load-request\0"
/*  1942 */ "Reads the DER encoded OCSP response from file\0"
/*  1988 */ "LOAD_RESPONSE\0"
/*  2002 */ "load-response\0"
/*  2016 */ "Ignore any verification errors\0"
/*  2047 */ "IGNORE_ERRORS\0"
/*  2061 */ "ignore-errors\0"
/*  2075 */ "Allow broken algorithms, such as MD5 for verification\0"
/*  2129 */ "VERIFY_ALLOW_BROKEN\0"
/*  2149 */ "verify-allow-broken\0"
/*  2169 */ "display extended usage information and exit\0"
/*  2213 */ "help\0"
/*  2218 */ "extended usage information passed thru pager\0"
/*  2263 */ "more-help\0"
/*  2273 */ "output version information and exit\0"
/*  2309 */ "version\0"
/*  2317 */ "OCSPTOOL\0"
/*  2326 */ "ocsptool - GnuTLS OCSP tool\n"
            "Usage:  %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n\0"
/*  2412 */ "bugs@gnutls.org\0"
/*  2428 */ "\n\0"
/*  2430 */ "ocsptool is a program that can parse and print information about OCSP\n"
            "requests/responses, generate requests and verify responses.  Unlike other\n"
            "GnuTLS applications it outputs DER encoded structures by default unless the\n"
            "'--outpem' option is specified.\n\0"
/*  2683 */ "ocsptool 3.6.9\0"
/*  2698 */ "ocsptool [options]\n"
            "ocsptool --help for usage instructions.\n";

/**
 *  debug option description:
 */
/** Descriptive text for the debug option */
#define DEBUG_DESC      (ocsptool_opt_strs+888)
/** Upper-cased name for the debug option */
#define DEBUG_NAME      (ocsptool_opt_strs+905)
/** Name string for the debug option */
#define DEBUG_name      (ocsptool_opt_strs+911)
/** Compiled in flag settings for the debug option */
#define DEBUG_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_NUMERIC))

/**
 *  verbose option description:
 */
/** Descriptive text for the verbose option */
#define VERBOSE_DESC      (ocsptool_opt_strs+917)
/** Upper-cased name for the verbose option */
#define VERBOSE_NAME      (ocsptool_opt_strs+937)
/** Name string for the verbose option */
#define VERBOSE_name      (ocsptool_opt_strs+945)
/** Compiled in flag settings for the verbose option */
#define VERBOSE_FLAGS     (OPTST_DISABLED)

/**
 *  infile option description:
 */
/** Descriptive text for the infile option */
#define INFILE_DESC      (ocsptool_opt_strs+953)
/** Upper-cased name for the infile option */
#define INFILE_NAME      (ocsptool_opt_strs+964)
/** Name string for the infile option */
#define INFILE_name      (ocsptool_opt_strs+971)
/** Compiled in flag settings for the infile option */
#define INFILE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  outfile option description:
 */
/** Descriptive text for the outfile option */
#define OUTFILE_DESC      (ocsptool_opt_strs+978)
/** Upper-cased name for the outfile option */
#define OUTFILE_NAME      (ocsptool_opt_strs+990)
/** Name string for the outfile option */
#define OUTFILE_name      (ocsptool_opt_strs+998)
/** Compiled in flag settings for the outfile option */
#define OUTFILE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING))

/**
 *  ask option description:
 */
/** Descriptive text for the ask option */
#define ASK_DESC      (ocsptool_opt_strs+1006)
/** Upper-cased name for the ask option */
#define ASK_NAME      (ocsptool_opt_strs+1056)
/** Name string for the ask option */
#define ASK_name      (ocsptool_opt_strs+1060)
/** Compiled in flag settings for the ask option */
#define ASK_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_STRING) | OPTST_ARG_OPTIONAL)

/**
 *  verify-response option description:
 */
/** Descriptive text for the verify-response option */
#define VERIFY_RESPONSE_DESC      (ocsptool_opt_strs+1064)
/** Upper-cased name for the verify-response option */
#define VERIFY_RESPONSE_NAME      (ocsptool_opt_strs+1080)
/** Name string for the verify-response option */
#define VERIFY_RESPONSE_name      (ocsptool_opt_strs+1096)
/** Compiled in flag settings for the verify-response option */
#define VERIFY_RESPONSE_FLAGS     (OPTST_DISABLED)

/**
 *  request-info option description:
 */
/** Descriptive text for the request-info option */
#define REQUEST_INFO_DESC      (ocsptool_opt_strs+1112)
/** Upper-cased name for the request-info option */
#define REQUEST_INFO_NAME      (ocsptool_opt_strs+1148)
/** Name string for the request-info option */
#define REQUEST_INFO_name      (ocsptool_opt_strs+1161)
/** Compiled in flag settings for the request-info option */
#define REQUEST_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  response-info option description:
 */
/** Descriptive text for the response-info option */
#define RESPONSE_INFO_DESC      (ocsptool_opt_strs+1174)
/** Upper-cased name for the response-info option */
#define RESPONSE_INFO_NAME      (ocsptool_opt_strs+1211)
/** Name string for the response-info option */
#define RESPONSE_INFO_name      (ocsptool_opt_strs+1225)
/** Compiled in flag settings for the response-info option */
#define RESPONSE_INFO_FLAGS     (OPTST_DISABLED)

/**
 *  generate-request option description:
 */
/** Descriptive text for the generate-request option */
#define GENERATE_REQUEST_DESC      (ocsptool_opt_strs+1239)
/** Upper-cased name for the generate-request option */
#define GENERATE_REQUEST_NAME      (ocsptool_opt_strs+1265)
/** Name string for the generate-request option */
#define GENERATE_REQUEST_name      (ocsptool_opt_strs+1282)
/** Compiled in flag settings for the generate-request option */
#define GENERATE_REQUEST_FLAGS     (OPTST_DISABLED)

/**
 *  nonce option description:
 */
/** Descriptive text for the nonce option */
#define NONCE_DESC      (ocsptool_opt_strs+1299)
/** Upper-cased name for the nonce option */
#define NONCE_NAME      (ocsptool_opt_strs+1336)
/** disablement name for the nonce option */
#define NOT_NONCE_name  (ocsptool_opt_strs+1342)
/** disablement prefix for the nonce option */
#define NOT_NONCE_PFX   (ocsptool_opt_strs+1351)
/** Name string for the nonce option */
#define NONCE_name      (NOT_NONCE_name + 3)
/** Compiled in flag settings for the nonce option */
#define NONCE_FLAGS     (OPTST_DISABLED)

/**
 *  load-chain option description:
 */
/** Descriptive text for the load-chain option */
#define LOAD_CHAIN_DESC      (ocsptool_opt_strs+1354)
/** Upper-cased name for the load-chain option */
#define LOAD_CHAIN_NAME      (ocsptool_opt_strs+1408)
/** Name string for the load-chain option */
#define LOAD_CHAIN_name      (ocsptool_opt_strs+1419)
/** Compiled in flag settings for the load-chain option */
#define LOAD_CHAIN_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  load-issuer option description:
 */
/** Descriptive text for the load-issuer option */
#define LOAD_ISSUER_DESC      (ocsptool_opt_strs+1430)
/** Upper-cased name for the load-issuer option */
#define LOAD_ISSUER_NAME      (ocsptool_opt_strs+1467)
/** Name string for the load-issuer option */
#define LOAD_ISSUER_name      (ocsptool_opt_strs+1479)
/** Compiled in flag settings for the load-issuer option */
#define LOAD_ISSUER_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  load-cert option description:
 */
/** Descriptive text for the load-cert option */
#define LOAD_CERT_DESC      (ocsptool_opt_strs+1491)
/** Upper-cased name for the load-cert option */
#define LOAD_CERT_NAME      (ocsptool_opt_strs+1532)
/** Name string for the load-cert option */
#define LOAD_CERT_name      (ocsptool_opt_strs+1542)
/** Compiled in flag settings for the load-cert option */
#define LOAD_CERT_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  load-trust option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the load-trust option */
#define LOAD_TRUST_DESC      (ocsptool_opt_strs+1552)
/** Upper-cased name for the load-trust option */
#define LOAD_TRUST_NAME      (ocsptool_opt_strs+1586)
/** Name string for the load-trust option */
#define LOAD_TRUST_name      (ocsptool_opt_strs+1597)
/** Other options that appear in conjunction with the load-trust option */
static int const aLoad_TrustCantList[] = {
    INDEX_OPT_LOAD_SIGNER, NO_EQUIVALENT };
/** Compiled in flag settings for the load-trust option */
#define LOAD_TRUST_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  load-signer option description with
 *  "Must also have options" and "Incompatible options":
 */
/** Descriptive text for the load-signer option */
#define LOAD_SIGNER_DESC      (ocsptool_opt_strs+1608)
/** Upper-cased name for the load-signer option */
#define LOAD_SIGNER_NAME      (ocsptool_opt_strs+1649)
/** Name string for the load-signer option */
#define LOAD_SIGNER_name      (ocsptool_opt_strs+1661)
/** Other options that appear in conjunction with the load-signer option */
static int const aLoad_SignerCantList[] = {
    INDEX_OPT_LOAD_TRUST, NO_EQUIVALENT };
/** Compiled in flag settings for the load-signer option */
#define LOAD_SIGNER_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  inder option description:
 */
/** Descriptive text for the inder option */
#define INDER_DESC      (ocsptool_opt_strs+1673)
/** Upper-cased name for the inder option */
#define INDER_NAME      (ocsptool_opt_strs+1728)
/** disablement name for the inder option */
#define NOT_INDER_name  (ocsptool_opt_strs+1734)
/** disablement prefix for the inder option */
#define NOT_INDER_PFX   (ocsptool_opt_strs+1351)
/** Name string for the inder option */
#define INDER_name      (NOT_INDER_name + 3)
/** Compiled in flag settings for the inder option */
#define INDER_FLAGS     (OPTST_DISABLED)

/**
 *  outder option description:
 */
/** Descriptive text for the outder option */
#define OUTDER_DESC      (ocsptool_opt_strs+1743)
/** Upper-cased name for the outder option */
#define OUTDER_NAME      (ocsptool_opt_strs+1804)
/** Name string for the outder option */
#define OUTDER_name      (ocsptool_opt_strs+1811)
/** Compiled in flag settings for the outder option */
#define OUTDER_FLAGS     (OPTST_DISABLED)

/**
 *  outpem option description:
 */
/** Descriptive text for the outpem option */
#define OUTPEM_DESC      (ocsptool_opt_strs+1818)
/** Upper-cased name for the outpem option */
#define OUTPEM_NAME      (ocsptool_opt_strs+1857)
/** Name string for the outpem option */
#define OUTPEM_name      (ocsptool_opt_strs+1864)
/** Compiled in flag settings for the outpem option */
#define OUTPEM_FLAGS     (OPTST_DISABLED)

/**
 *  load-request option description:
 */
/** Descriptive text for the load-request option */
#define LOAD_REQUEST_DESC      (ocsptool_opt_strs+1871)
/** Upper-cased name for the load-request option */
#define LOAD_REQUEST_NAME      (ocsptool_opt_strs+1916)
/** Name string for the load-request option */
#define LOAD_REQUEST_name      (ocsptool_opt_strs+1929)
/** Compiled in flag settings for the load-request option */
#define LOAD_REQUEST_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  load-response option description:
 */
/** Descriptive text for the load-response option */
#define LOAD_RESPONSE_DESC      (ocsptool_opt_strs+1942)
/** Upper-cased name for the load-response option */
#define LOAD_RESPONSE_NAME      (ocsptool_opt_strs+1988)
/** Name string for the load-response option */
#define LOAD_RESPONSE_name      (ocsptool_opt_strs+2002)
/** Compiled in flag settings for the load-response option */
#define LOAD_RESPONSE_FLAGS     (OPTST_DISABLED \
        | OPTST_SET_ARGTYPE(OPARG_TYPE_FILE))

/**
 *  ignore-errors option description:
 */
/** Descriptive text for the ignore-errors option */
#define IGNORE_ERRORS_DESC      (ocsptool_opt_strs+2016)
/** Upper-cased name for the ignore-errors option */
#define IGNORE_ERRORS_NAME      (ocsptool_opt_strs+2047)
/** Name string for the ignore-errors option */
#define IGNORE_ERRORS_name      (ocsptool_opt_strs+2061)
/** Compiled in flag settings for the ignore-errors option */
#define IGNORE_ERRORS_FLAGS     (OPTST_DISABLED)

/**
 *  verify-allow-broken option description:
 */
/** Descriptive text for the verify-allow-broken option */
#define VERIFY_ALLOW_BROKEN_DESC      (ocsptool_opt_strs+2075)
/** Upper-cased name for the verify-allow-broken option */
#define VERIFY_ALLOW_BROKEN_NAME      (ocsptool_opt_strs+2129)
/** Name string for the verify-allow-broken option */
#define VERIFY_ALLOW_BROKEN_name      (ocsptool_opt_strs+2149)
/** Compiled in flag settings for the verify-allow-broken option */
#define VERIFY_ALLOW_BROKEN_FLAGS     (OPTST_DISABLED)

/*
 *  Help/More_Help/Version option descriptions:
 */
#define HELP_DESC       (ocsptool_opt_strs+2169)
#define HELP_name       (ocsptool_opt_strs+2213)
#ifdef HAVE_WORKING_FORK
#define MORE_HELP_DESC  (ocsptool_opt_strs+2218)
#define MORE_HELP_name  (ocsptool_opt_strs+2263)
#define MORE_HELP_FLAGS (OPTST_IMM | OPTST_NO_INIT)
#else
#define MORE_HELP_DESC  HELP_DESC
#define MORE_HELP_name  HELP_name
#define MORE_HELP_FLAGS (OPTST_OMITTED | OPTST_NO_INIT)
#endif
#ifdef NO_OPTIONAL_OPT_ARGS
#  define VER_FLAGS     (OPTST_IMM | OPTST_NO_INIT)
#else
#  define VER_FLAGS     (OPTST_SET_ARGTYPE(OPARG_TYPE_STRING) | \
                         OPTST_ARG_OPTIONAL | OPTST_IMM | OPTST_NO_INIT)
#endif
#define VER_DESC        (ocsptool_opt_strs+2273)
#define VER_name        (ocsptool_opt_strs+2309)
/**
 *  Declare option callback procedures
 */
extern tOptProc
    optionBooleanVal,   optionNestedVal,    optionNumericVal,
    optionPagedUsage,   optionPrintVersion, optionResetOpt,
    optionStackArg,     optionTimeDate,     optionTimeVal,
    optionUnstackArg,   optionVendorOption;
static tOptProc
    doOptDebug,         doOptInfile,        doOptLoad_Cert,
    doOptLoad_Chain,    doOptLoad_Issuer,   doOptLoad_Request,
    doOptLoad_Response, doOptLoad_Signer,   doOptLoad_Trust,
    doUsageOpt;
#define VER_PROC        optionPrintVersion

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 *  Define the ocsptool Option Descriptions.
 * This is an array of OPTION_CT entries, one for each
 * option that the ocsptool program responds to.
 */
static tOptDesc optDesc[OPTION_CT] = {
  {  /* entry idx, value */ 0, VALUE_OPT_DEBUG,
     /* equiv idx, value */ 0, VALUE_OPT_DEBUG,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ DEBUG_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --debug */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptDebug,
     /* desc, NAME, name */ DEBUG_DESC, DEBUG_NAME, DEBUG_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 1, VALUE_OPT_VERBOSE,
     /* equiv idx, value */ 1, VALUE_OPT_VERBOSE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, NOLIMIT, 0,
     /* opt state flags  */ VERBOSE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verbose */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERBOSE_DESC, VERBOSE_NAME, VERBOSE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 2, VALUE_OPT_INFILE,
     /* equiv idx, value */ 2, VALUE_OPT_INFILE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ INFILE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --infile */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptInfile,
     /* desc, NAME, name */ INFILE_DESC, INFILE_NAME, INFILE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 3, VALUE_OPT_OUTFILE,
     /* equiv idx, value */ 3, VALUE_OPT_OUTFILE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OUTFILE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --outfile */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ OUTFILE_DESC, OUTFILE_NAME, OUTFILE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 4, VALUE_OPT_ASK,
     /* equiv idx, value */ 4, VALUE_OPT_ASK,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ ASK_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --ask */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ ASK_DESC, ASK_NAME, ASK_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 5, VALUE_OPT_VERIFY_RESPONSE,
     /* equiv idx, value */ 5, VALUE_OPT_VERIFY_RESPONSE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERIFY_RESPONSE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verify-response */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERIFY_RESPONSE_DESC, VERIFY_RESPONSE_NAME, VERIFY_RESPONSE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 6, VALUE_OPT_REQUEST_INFO,
     /* equiv idx, value */ 6, VALUE_OPT_REQUEST_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ REQUEST_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --request-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ REQUEST_INFO_DESC, REQUEST_INFO_NAME, REQUEST_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 7, VALUE_OPT_RESPONSE_INFO,
     /* equiv idx, value */ 7, VALUE_OPT_RESPONSE_INFO,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ RESPONSE_INFO_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --response-info */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ RESPONSE_INFO_DESC, RESPONSE_INFO_NAME, RESPONSE_INFO_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 8, VALUE_OPT_GENERATE_REQUEST,
     /* equiv idx, value */ 8, VALUE_OPT_GENERATE_REQUEST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ GENERATE_REQUEST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --generate-request */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ GENERATE_REQUEST_DESC, GENERATE_REQUEST_NAME, GENERATE_REQUEST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 9, VALUE_OPT_NONCE,
     /* equiv idx, value */ 9, VALUE_OPT_NONCE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ NONCE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --nonce */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ NONCE_DESC, NONCE_NAME, NONCE_name,
     /* disablement strs */ NOT_NONCE_name, NOT_NONCE_PFX },

  {  /* entry idx, value */ 10, VALUE_OPT_LOAD_CHAIN,
     /* equiv idx, value */ 10, VALUE_OPT_LOAD_CHAIN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_CHAIN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-chain */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptLoad_Chain,
     /* desc, NAME, name */ LOAD_CHAIN_DESC, LOAD_CHAIN_NAME, LOAD_CHAIN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 11, VALUE_OPT_LOAD_ISSUER,
     /* equiv idx, value */ 11, VALUE_OPT_LOAD_ISSUER,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_ISSUER_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-issuer */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptLoad_Issuer,
     /* desc, NAME, name */ LOAD_ISSUER_DESC, LOAD_ISSUER_NAME, LOAD_ISSUER_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 12, VALUE_OPT_LOAD_CERT,
     /* equiv idx, value */ 12, VALUE_OPT_LOAD_CERT,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_CERT_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-cert */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptLoad_Cert,
     /* desc, NAME, name */ LOAD_CERT_DESC, LOAD_CERT_NAME, LOAD_CERT_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 13, VALUE_OPT_LOAD_TRUST,
     /* equiv idx, value */ 13, VALUE_OPT_LOAD_TRUST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_TRUST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-trust */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aLoad_TrustCantList,
     /* option proc      */ doOptLoad_Trust,
     /* desc, NAME, name */ LOAD_TRUST_DESC, LOAD_TRUST_NAME, LOAD_TRUST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 14, VALUE_OPT_LOAD_SIGNER,
     /* equiv idx, value */ 14, VALUE_OPT_LOAD_SIGNER,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_SIGNER_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-signer */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, aLoad_SignerCantList,
     /* option proc      */ doOptLoad_Signer,
     /* desc, NAME, name */ LOAD_SIGNER_DESC, LOAD_SIGNER_NAME, LOAD_SIGNER_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 15, VALUE_OPT_INDER,
     /* equiv idx, value */ 15, VALUE_OPT_INDER,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ INDER_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --inder */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ INDER_DESC, INDER_NAME, INDER_name,
     /* disablement strs */ NOT_INDER_name, NOT_INDER_PFX },

  {  /* entry idx, value */ 16, VALUE_OPT_OUTDER,
     /* equiv idx, value */ 16, VALUE_OPT_OUTDER,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OUTDER_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --outder */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ OUTDER_DESC, OUTDER_NAME, OUTDER_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 17, VALUE_OPT_OUTPEM,
     /* equiv idx, value */ 17, VALUE_OPT_OUTPEM,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OUTPEM_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --outpem */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ OUTPEM_DESC, OUTPEM_NAME, OUTPEM_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 18, VALUE_OPT_LOAD_REQUEST,
     /* equiv idx, value */ 18, VALUE_OPT_LOAD_REQUEST,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_REQUEST_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-request */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptLoad_Request,
     /* desc, NAME, name */ LOAD_REQUEST_DESC, LOAD_REQUEST_NAME, LOAD_REQUEST_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 19, VALUE_OPT_LOAD_RESPONSE,
     /* equiv idx, value */ 19, VALUE_OPT_LOAD_RESPONSE,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ LOAD_RESPONSE_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --load-response */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doOptLoad_Response,
     /* desc, NAME, name */ LOAD_RESPONSE_DESC, LOAD_RESPONSE_NAME, LOAD_RESPONSE_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 20, VALUE_OPT_IGNORE_ERRORS,
     /* equiv idx, value */ 20, VALUE_OPT_IGNORE_ERRORS,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ IGNORE_ERRORS_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --ignore-errors */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ IGNORE_ERRORS_DESC, IGNORE_ERRORS_NAME, IGNORE_ERRORS_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ 21, VALUE_OPT_VERIFY_ALLOW_BROKEN,
     /* equiv idx, value */ 21, VALUE_OPT_VERIFY_ALLOW_BROKEN,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VERIFY_ALLOW_BROKEN_FLAGS, 0,
     /* last opt argumnt */ { NULL }, /* --verify-allow-broken */
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ NULL,
     /* desc, NAME, name */ VERIFY_ALLOW_BROKEN_DESC, VERIFY_ALLOW_BROKEN_NAME, VERIFY_ALLOW_BROKEN_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_VERSION, VALUE_OPT_VERSION,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_VERSION,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ VER_FLAGS, AOUSE_VERSION,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ VER_PROC,
     /* desc, NAME, name */ VER_DESC, NULL, VER_name,
     /* disablement strs */ NULL, NULL },



  {  /* entry idx, value */ INDEX_OPT_HELP, VALUE_OPT_HELP,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ OPTST_IMM | OPTST_NO_INIT, AOUSE_HELP,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL, NULL,
     /* option proc      */ doUsageOpt,
     /* desc, NAME, name */ HELP_DESC, NULL, HELP_name,
     /* disablement strs */ NULL, NULL },

  {  /* entry idx, value */ INDEX_OPT_MORE_HELP, VALUE_OPT_MORE_HELP,
     /* equiv idx value  */ NO_EQUIVALENT, VALUE_OPT_MORE_HELP,
     /* equivalenced to  */ NO_EQUIVALENT,
     /* min, max, act ct */ 0, 1, 0,
     /* opt state flags  */ MORE_HELP_FLAGS, AOUSE_MORE_HELP,
     /* last opt argumnt */ { NULL },
     /* arg list/cookie  */ NULL,
     /* must/cannot opts */ NULL,  NULL,
     /* option proc      */ optionPagedUsage,
     /* desc, NAME, name */ MORE_HELP_DESC, NULL, MORE_HELP_name,
     /* disablement strs */ NULL, NULL }
};


/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/** Reference to the upper cased version of ocsptool. */
#define zPROGNAME       (ocsptool_opt_strs+2317)
/** Reference to the title line for ocsptool usage. */
#define zUsageTitle     (ocsptool_opt_strs+2326)
/** There is no ocsptool configuration file. */
#define zRcName         NULL
/** There are no directories to search for ocsptool config files. */
#define apzHomeList     NULL
/** The ocsptool program bug email address. */
#define zBugsAddr       (ocsptool_opt_strs+2412)
/** Clarification/explanation of what ocsptool does. */
#define zExplain        (ocsptool_opt_strs+2428)
/** Extra detail explaining what ocsptool does. */
#define zDetail         (ocsptool_opt_strs+2430)
/** The full version string for ocsptool. */
#define zFullVersion    (ocsptool_opt_strs+2683)
/* extracted from optcode.tlib near line 342 */

#if defined(ENABLE_NLS)
# define OPTPROC_BASE OPTPROC_TRANSLATE | OPTPROC_NXLAT_OPT
  static tOptionXlateProc translate_option_strings;
#else
# define OPTPROC_BASE OPTPROC_NONE
# define translate_option_strings NULL
#endif /* ENABLE_NLS */

#define ocsptool_full_usage (NULL)
#define ocsptool_short_usage (ocsptool_opt_strs+2698)

#endif /* not defined __doxygen__ */

/*
 *  Create the static procedure(s) declared above.
 */
/**
 * The callout function that invokes the optionUsage function.
 *
 * @param[in] opts the AutoOpts option description structure
 * @param[in] od   the descriptor for the "help" (usage) option.
 * @noreturn
 */
static void
doUsageOpt(tOptions * opts, tOptDesc * od)
{
    int ex_code;
    ex_code = OCSPTOOL_EXIT_SUCCESS;
    optionUsage(&ocsptoolOptions, ex_code);
    /* NOTREACHED */
    exit(OCSPTOOL_EXIT_FAILURE);
    (void)opts;
    (void)od;
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the debug option.
 * Specifies the debug level.
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptDebug(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static struct {long rmin, rmax;} const rng[1] = {
        { 0 ,  9999 } };
    int  ix;

    if (pOptions <= OPTPROC_EMIT_LIMIT)
        goto emit_ranges;
    optionNumericVal(pOptions, pOptDesc);

    for (ix = 0; ix < 1; ix++) {
        if (pOptDesc->optArg.argInt < rng[ix].rmin)
            continue;  /* ranges need not be ordered. */
        if (pOptDesc->optArg.argInt == rng[ix].rmin)
            return;
        if (rng[ix].rmax == LONG_MIN)
            continue;
        if (pOptDesc->optArg.argInt <= rng[ix].rmax)
            return;
    }

    option_usage_fp = stderr;

 emit_ranges:
optionShowRange(pOptions, pOptDesc, VOIDP(rng), 1);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the infile option.
 *
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptInfile(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the load-chain option.
 *
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLoad_Chain(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the load-issuer option.
 *
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLoad_Issuer(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the load-cert option.
 *
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLoad_Cert(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the load-trust option.
 * When verifying an OCSP response read the trust anchors from the
 * provided file. When this is not provided, the system's trust anchors will be
 * used.
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLoad_Trust(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the load-signer option.
 *
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLoad_Signer(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the load-request option.
 *
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLoad_Request(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/**
 * Code to handle the load-response option.
 *
 * @param[in] pOptions the ocsptool options data structure
 * @param[in,out] pOptDesc the option descriptor for this option.
 */
static void
doOptLoad_Response(tOptions* pOptions, tOptDesc* pOptDesc)
{
    static teOptFileType const  type =
        FTYPE_MODE_MUST_EXIST + FTYPE_MODE_NO_OPEN;
    static tuFileMode           mode;
#ifndef O_CLOEXEC
#  define O_CLOEXEC 0
#endif
    mode.file_flags = O_CLOEXEC;

    /*
     * This function handles special invalid values for "pOptions"
     */
    optionFileCheck(pOptions, pOptDesc, type, mode);
}
/* extracted from optmain.tlib near line 1250 */

/**
 * The directory containing the data associated with ocsptool.
 */
#ifndef  PKGDATADIR
# define PKGDATADIR ""
#endif

/**
 * Information about the person or institution that packaged ocsptool
 * for the current distribution.
 */
#ifndef  WITH_PACKAGER
# define ocsptool_packager_info NULL
#else
/** Packager information for ocsptool. */
static char const ocsptool_packager_info[] =
    "Packaged by " WITH_PACKAGER

# ifdef WITH_PACKAGER_VERSION
        " ("WITH_PACKAGER_VERSION")"
# endif

# ifdef WITH_PACKAGER_BUG_REPORTS
    "\nReport ocsptool bugs to " WITH_PACKAGER_BUG_REPORTS
# endif
    "\n";
#endif
#ifndef __doxygen__

#endif /* __doxygen__ */
/**
 * The option definitions for ocsptool.  The one structure that
 * binds them all.
 */
tOptions ocsptoolOptions = {
    OPTIONS_STRUCT_VERSION,
    0, NULL,                    /* original argc + argv    */
    ( OPTPROC_BASE
    + OPTPROC_ERRSTOP
    + OPTPROC_SHORTOPT
    + OPTPROC_LONGOPT
    + OPTPROC_NO_REQ_OPT
    + OPTPROC_NEGATIONS
    + OPTPROC_NO_ARGS
    + OPTPROC_GNUUSAGE
    + OPTPROC_MISUSE ),
    0, NULL,                    /* current option index, current option */
    NULL,         NULL,         zPROGNAME,
    zRcName,      zCopyright,   zLicenseDescrip,
    zFullVersion, apzHomeList,  zUsageTitle,
    zExplain,     zDetail,      optDesc,
    zBugsAddr,                  /* address to send bugs to */
    NULL, NULL,                 /* extensions/saved state  */
    optionUsage, /* usage procedure */
    translate_option_strings,   /* translation procedure */
    /*
     *  Indexes to special options
     */
    { INDEX_OPT_MORE_HELP, /* more-help option index */
      NO_EQUIVALENT, /* save option index */
      NO_EQUIVALENT, /* '-#' option index */
      NO_EQUIVALENT /* index of default opt */
    },
    25 /* full option count */, 22 /* user option count */,
    ocsptool_full_usage, ocsptool_short_usage,
    NULL, NULL,
    PKGDATADIR, ocsptool_packager_info
};

#if ENABLE_NLS
/**
 * This code is designed to translate translatable option text for the
 * ocsptool program.  These translations happen upon entry
 * to optionProcess().
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#ifdef HAVE_DCGETTEXT
# include <gettext.h>
#endif
#include <autoopts/usage-txt.h>

static char * AO_gettext(char const * pz);
static void   coerce_it(void ** s);

/**
 * AutoGen specific wrapper function for gettext.  It relies on the macro _()
 * to convert from English to the target language, then strdup-duplicates the
 * result string.  It tries the "libopts" domain first, then whatever has been
 * set via the \a textdomain(3) call.
 *
 * @param[in] pz the input text used as a lookup key.
 * @returns the translated text (if there is one),
 *   or the original text (if not).
 */
static char *
AO_gettext(char const * pz)
{
    char * res;
    if (pz == NULL)
        return NULL;
#ifdef HAVE_DCGETTEXT
    /*
     * While processing the option_xlateable_txt data, try to use the
     * "libopts" domain.  Once we switch to the option descriptor data,
     * do *not* use that domain.
     */
    if (option_xlateable_txt.field_ct != 0) {
        res = dgettext("libopts", pz);
        if (res == pz)
            res = (char *)VOIDP(_(pz));
    } else
        res = (char *)VOIDP(_(pz));
#else
    res = (char *)VOIDP(_(pz));
#endif
    if (res == pz)
        return res;
    res = strdup(res);
    if (res == NULL) {
        fputs(_("No memory for duping translated strings\n"), stderr);
        exit(OCSPTOOL_EXIT_FAILURE);
    }
    return res;
}

/**
 * All the pointers we use are marked "* const", but they are stored in
 * writable memory.  Coerce the mutability and set the pointer.
 */
static void coerce_it(void ** s) { *s = AO_gettext(*s);
}

/**
 * Translate all the translatable strings in the ocsptoolOptions
 * structure defined above.  This is done only once.
 */
static void
translate_option_strings(void)
{
    tOptions * const opts = &ocsptoolOptions;

    /*
     *  Guard against re-translation.  It won't work.  The strings will have
     *  been changed by the first pass through this code.  One shot only.
     */
    if (option_xlateable_txt.field_ct != 0) {
        /*
         *  Do the translations.  The first pointer follows the field count
         *  field.  The field count field is the size of a pointer.
         */
        char ** ppz = (char**)VOIDP(&(option_xlateable_txt));
        int     ix  = option_xlateable_txt.field_ct;

        do {
            ppz++; /* skip over field_ct */
            *ppz = AO_gettext(*ppz);
        } while (--ix > 0);
        /* prevent re-translation and disable "libopts" domain lookup */
        option_xlateable_txt.field_ct = 0;

        coerce_it(VOIDP(&(opts->pzCopyright)));
        coerce_it(VOIDP(&(opts->pzCopyNotice)));
        coerce_it(VOIDP(&(opts->pzFullVersion)));
        coerce_it(VOIDP(&(opts->pzUsageTitle)));
        coerce_it(VOIDP(&(opts->pzExplain)));
        coerce_it(VOIDP(&(opts->pzDetail)));
        {
            tOptDesc * od = opts->pOptDesc;
            for (ix = opts->optCt; ix > 0; ix--, od++)
                coerce_it(VOIDP(&(od->pzText)));
        }
    }
}
#endif /* ENABLE_NLS */

#ifdef DO_NOT_COMPILE_THIS_CODE_IT_IS_FOR_GETTEXT
/** I18N function strictly for xgettext.  Do not compile. */
static void bogus_function(void) {
  /* TRANSLATORS:

     The following dummy function was crated solely so that xgettext can
     extract the correct strings.  These strings are actually referenced
     by a field name in the ocsptoolOptions structure noted in the
     comments below.  The literal text is defined in ocsptool_opt_strs.

     NOTE: the strings below are segmented with respect to the source string
     ocsptool_opt_strs.  The strings above are handed off for translation
     at run time a paragraph at a time.  Consequently, they are presented here
     for translation a paragraph at a time.

     ALSO: often the description for an option will reference another option
     by name.  These are set off with apostrophe quotes (I hope).  Do not
     translate option names.
   */
  /* referenced via ocsptoolOptions.pzCopyright */
  puts(_("ocsptool 3.6.9\n\
Copyright (C) 2000-2019 Free Software Foundation, and others, all rights reserved.\n\
This is free software. It is licensed for use, modification and\n\
redistribution under the terms of the GNU General Public License,\n\
version 3 or later <http://gnu.org/licenses/gpl.html>\n"));

  /* referenced via ocsptoolOptions.pzCopyNotice */
  puts(_("ocsptool is free software: you can redistribute it and/or modify it under\n\
the terms of the GNU General Public License as published by the Free\n\
Software Foundation, either version 3 of the License, or (at your option)\n\
any later version.\n\n"));
  puts(_("ocsptool is distributed in the hope that it will be useful, but WITHOUT ANY\n\
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS\n\
FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more\n\
details.\n\n"));
  puts(_("You should have received a copy of the GNU General Public License along\n\
with this program.  If not, see <http://www.gnu.org/licenses/>.\n"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Enable debugging"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("More verbose output"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Input file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Output file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Ask an OCSP/HTTP server on a certificate validity"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Verify response"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Print information on a OCSP request"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Print information on a OCSP response"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Generates an OCSP request"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Use (or not) a nonce to OCSP request"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Reads a set of certificates forming a chain from file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Reads issuer's certificate from file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Reads the certificate to check from file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Read OCSP trust anchors from file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Reads the OCSP response signer from file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Use DER format for input certificates and private keys"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Use DER format for output of responses (this is the default)"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Use PEM format for output of responses"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Reads the DER encoded OCSP request from file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Reads the DER encoded OCSP response from file"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Ignore any verification errors"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("Allow broken algorithms, such as MD5 for verification"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("display extended usage information and exit"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("extended usage information passed thru pager"));

  /* referenced via ocsptoolOptions.pOptDesc->pzText */
  puts(_("output version information and exit"));

  /* referenced via ocsptoolOptions.pzUsageTitle */
  puts(_("ocsptool - GnuTLS OCSP tool\n\
Usage:  %s [ -<flag> [<val>] | --<name>[{=| }<val>] ]...\n"));

  /* referenced via ocsptoolOptions.pzExplain */
  puts(_("\n"));

  /* referenced via ocsptoolOptions.pzDetail */
  puts(_("ocsptool is a program that can parse and print information about OCSP\n\
requests/responses, generate requests and verify responses.  Unlike other\n\
GnuTLS applications it outputs DER encoded structures by default unless the\n\
'--outpem' option is specified.\n"));

  /* referenced via ocsptoolOptions.pzFullVersion */
  puts(_("ocsptool 3.6.9"));

  /* referenced via ocsptoolOptions.pzFullUsage */
  puts(_("<<<NOT-FOUND>>>"));

  /* referenced via ocsptoolOptions.pzShortUsage */
  puts(_("ocsptool [options]\n\
ocsptool --help for usage instructions.\n"));
  /* LIBOPTS-MESSAGES: */
#line 67 "../autoopts.c"
  puts(_("allocation of %d bytes failed\n"));
#line 89 "../autoopts.c"
  puts(_("allocation of %d bytes failed\n"));
#line 48 "../init.c"
  puts(_("AutoOpts function called without option descriptor\n"));
#line 81 "../init.c"
  puts(_("\tThis exceeds the compiled library version:  "));
#line 79 "../init.c"
  puts(_("Automated Options Processing Error!\n"
       "\t%s called AutoOpts function with structure version %d:%d:%d.\n"));
#line 78 "../autoopts.c"
  puts(_("realloc of %d bytes at 0x%p failed\n"));
#line 83 "../init.c"
  puts(_("\tThis is less than the minimum library version:  "));
#line 121 "../version.c"
  puts(_("Automated Options version %s\n"
       "\tCopyright (C) 1999-2017 by Bruce Korb - all rights reserved\n"));
#line 49 "../makeshell.c"
  puts(_("(AutoOpts bug):  %s.\n"));
#line 90 "../reset.c"
  puts(_("optionResetOpt() called, but reset-option not configured"));
#line 241 "../usage.c"
  puts(_("could not locate the 'help' option"));
#line 330 "../autoopts.c"
  puts(_("optionProcess() was called with invalid data"));
#line 697 "../usage.c"
  puts(_("invalid argument type specified"));
#line 568 "../find.c"
  puts(_("defaulted to option with optional arg"));
#line 76 "../alias.c"
  puts(_("aliasing option is out of range."));
#line 210 "../enum.c"
  puts(_("%s error:  the keyword '%s' is ambiguous for %s\n"));
#line 78 "../find.c"
  puts(_("  The following options match:\n"));
#line 263 "../find.c"
  puts(_("%s: ambiguous option name: %s (matches %d options)\n"));
#line 161 "../check.c"
  puts(_("%s: Command line arguments required\n"));
#line 43 "../alias.c"
  puts(_("%d %s%s options allowed\n"));
#line 56 "../makeshell.c"
  puts(_("%s error %d (%s) calling %s for '%s'\n"));
#line 268 "../makeshell.c"
  puts(_("interprocess pipe"));
#line 171 "../version.c"
  puts(_("error: version option argument '%c' invalid.  Use:\n"
       "\t'v' - version only\n"
       "\t'c' - version and copyright\n"
       "\t'n' - version and full copyright notice\n"));
#line 58 "../check.c"
  puts(_("%s error:  the '%s' and '%s' options conflict\n"));
#line 187 "../find.c"
  puts(_("%s: The '%s' option has been disabled."));
#line 400 "../find.c"
  puts(_("%s: The '%s' option has been disabled."));
#line 38 "../alias.c"
  puts(_("-equivalence"));
#line 439 "../find.c"
  puts(_("%s: illegal option -- %c\n"));
#line 110 "../reset.c"
  puts(_("%s: illegal option -- %c\n"));
#line 241 "../find.c"
  puts(_("%s: illegal option -- %s\n"));
#line 740 "../find.c"
  puts(_("%s: illegal option -- %s\n"));
#line 118 "../reset.c"
  puts(_("%s: illegal option -- %s\n"));
#line 305 "../find.c"
  puts(_("%s: unknown vendor extension option -- %s\n"));
#line 135 "../enum.c"
  puts(_("  or an integer from %d through %d\n"));
#line 145 "../enum.c"
  puts(_("  or an integer from %d through %d\n"));
#line 696 "../usage.c"
  puts(_("%s error:  invalid option descriptor for %s\n"));
#line 1030 "../usage.c"
  puts(_("%s error:  invalid option descriptor for %s\n"));
#line 355 "../find.c"
  puts(_("%s: invalid option name: %s\n"));
#line 497 "../find.c"
  puts(_("%s: The '%s' option requires an argument.\n"));
#line 150 "../autoopts.c"
  puts(_("(AutoOpts bug):  Equivalenced option '%s' was equivalenced to both\n"
       "\t'%s' and '%s'."));
#line 94 "../check.c"
  puts(_("%s error:  The %s option is required\n"));
#line 602 "../find.c"
  puts(_("%s: The '%s' option cannot have an argument.\n"));
#line 151 "../check.c"
  puts(_("%s: Command line arguments are not allowed.\n"));
#line 568 "../save.c"
  puts(_("error %d (%s) creating %s\n"));
#line 210 "../enum.c"
  puts(_("%s error:  '%s' does not match any %s keywords.\n"));
#line 93 "../reset.c"
  puts(_("%s error: The '%s' option requires an argument.\n"));
#line 122 "../save.c"
  puts(_("error %d (%s) stat-ing %s\n"));
#line 175 "../save.c"
  puts(_("error %d (%s) stat-ing %s\n"));
#line 143 "../restore.c"
  puts(_("%s error: no saved option state\n"));
#line 225 "../autoopts.c"
  puts(_("'%s' is not a command line option.\n"));
#line 113 "../time.c"
  puts(_("%s error:  '%s' is not a recognizable date/time.\n"));
#line 50 "../time.c"
  puts(_("%s error:  '%s' is not a recognizable time duration.\n"));
#line 92 "../check.c"
  puts(_("%s error:  The %s option must appear %d times.\n"));
#line 165 "../numeric.c"
  puts(_("%s error:  '%s' is not a recognizable number.\n"));
#line 176 "../enum.c"
  puts(_("%s error:  %s exceeds %s keyword count\n"));
#line 279 "../usage.c"
  puts(_("Try '%s %s' for more information.\n"));
#line 45 "../alias.c"
  puts(_("one %s%s option allowed\n"));
#line 170 "../makeshell.c"
  puts(_("standard output"));
#line 905 "../makeshell.c"
  puts(_("standard output"));
#line 223 "../usage.c"
  puts(_("standard output"));
#line 364 "../usage.c"
  puts(_("standard output"));
#line 574 "../usage.c"
  puts(_("standard output"));
#line 178 "../version.c"
  puts(_("standard output"));
#line 223 "../usage.c"
  puts(_("standard error"));
#line 364 "../usage.c"
  puts(_("standard error"));
#line 574 "../usage.c"
  puts(_("standard error"));
#line 178 "../version.c"
  puts(_("standard error"));
#line 170 "../makeshell.c"
  puts(_("write"));
#line 905 "../makeshell.c"
  puts(_("write"));
#line 222 "../usage.c"
  puts(_("write"));
#line 363 "../usage.c"
  puts(_("write"));
#line 573 "../usage.c"
  puts(_("write"));
#line 177 "../version.c"
  puts(_("write"));
#line 60 "../numeric.c"
  puts(_("%s error:  %s option value %ld is out of range.\n"));
#line 44 "../check.c"
  puts(_("%s error:  %s option requires the %s option\n"));
#line 121 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 174 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 193 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
#line 567 "../save.c"
  puts(_("%s warning:  cannot save options - %s not regular file\n"));
  /* END-LIBOPTS-MESSAGES */

  /* USAGE-TEXT: */
#line 822 "../usage.c"
  puts(_("\t\t\t\t- an alternate for '%s'\n"));
#line 1097 "../usage.c"
  puts(_("Version, usage and configuration options:"));
#line 873 "../usage.c"
  puts(_("\t\t\t\t- default option for unnamed options\n"));
#line 786 "../usage.c"
  puts(_("\t\t\t\t- disabled as '--%s'\n"));
#line 1066 "../usage.c"
  puts(_(" --- %-14s %s\n"));
#line 1064 "../usage.c"
  puts(_("This option has been disabled"));
#line 813 "../usage.c"
  puts(_("\t\t\t\t- enabled by default\n"));
#line 40 "../alias.c"
  puts(_("%s error:  only "));
#line 1143 "../usage.c"
  puts(_(" - examining environment variables named %s_*\n"));
#line 168 "../file.c"
  puts(_("\t\t\t\t- file must not pre-exist\n"));
#line 172 "../file.c"
  puts(_("\t\t\t\t- file must pre-exist\n"));
#line 329 "../usage.c"
  puts(_("Options are specified by doubled hyphens and their name or by a single\n"
       "hyphen and the flag character.\n"));
#line 882 "../makeshell.c"
  puts(_("\n"
       "= = = = = = = =\n\n"
       "This incarnation of genshell will produce\n"
       "a shell script to parse the options for %s:\n\n"));
#line 142 "../enum.c"
  puts(_("  or an integer mask with any of the lower %d bits set\n"));
#line 846 "../usage.c"
  puts(_("\t\t\t\t- is a set membership option\n"));
#line 867 "../usage.c"
  puts(_("\t\t\t\t- must appear between %d and %d times\n"));
#line 331 "../usage.c"
  puts(_("Options are specified by single or double hyphens and their name.\n"));
#line 853 "../usage.c"
  puts(_("\t\t\t\t- may appear multiple times\n"));
#line 840 "../usage.c"
  puts(_("\t\t\t\t- may not be preset\n"));
#line 1258 "../usage.c"
  puts(_("   Arg Option-Name    Description\n"));
#line 1194 "../usage.c"
  puts(_("  Flg Arg Option-Name    Description\n"));
#line 1252 "../usage.c"
  puts(_("  Flg Arg Option-Name    Description\n"));
#line 1253 "../usage.c"
  puts(_(" %3s %s"));
#line 1259 "../usage.c"
  puts(_(" %3s %s"));
#line 336 "../usage.c"
  puts(_("The '-#<number>' option may omit the hash char\n"));
#line 332 "../usage.c"
  puts(_("All arguments are named options.\n"));
#line 920 "../usage.c"
  puts(_(" - reading file %s"));
#line 358 "../usage.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 100 "../version.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 129 "../version.c"
  puts(_("\n"
       "Please send bug reports to:  <%s>\n"));
#line 852 "../usage.c"
  puts(_("\t\t\t\t- may NOT appear - preset only\n"));
#line 893 "../usage.c"
  puts(_("\n"
       "The following option preset mechanisms are supported:\n"));
#line 1141 "../usage.c"
  puts(_("\n"
       "The following option preset mechanisms are supported:\n"));
#line 631 "../usage.c"
  puts(_("prohibits these options:\n"));
#line 626 "../usage.c"
  puts(_("prohibits the option '%s'\n"));
#line 81 "../numeric.c"
  puts(_("%s%ld to %ld"));
#line 79 "../numeric.c"
  puts(_("%sgreater than or equal to %ld"));
#line 75 "../numeric.c"
  puts(_("%s%ld exactly"));
#line 68 "../numeric.c"
  puts(_("%sit must lie in one of the ranges:\n"));
#line 68 "../numeric.c"
  puts(_("%sit must be in the range:\n"));
#line 88 "../numeric.c"
  puts(_(", or\n"));
#line 66 "../numeric.c"
  puts(_("%sis scalable with a suffix: k/K/m/M/g/G/t/T\n"));
#line 77 "../numeric.c"
  puts(_("%sless than or equal to %ld"));
#line 339 "../usage.c"
  puts(_("Operands and options may be intermixed.  They will be reordered.\n"));
#line 601 "../usage.c"
  puts(_("requires the option '%s'\n"));
#line 604 "../usage.c"
  puts(_("requires these options:\n"));
#line 1270 "../usage.c"
  puts(_("   Arg Option-Name   Req?  Description\n"));
#line 1264 "../usage.c"
  puts(_("  Flg Arg Option-Name   Req?  Description\n"));
#line 143 "../enum.c"
  puts(_("or you may use a numeric representation.  Preceding these with a '!'\n"
       "will clear the bits, specifying 'none' will clear all bits, and 'all'\n"
       "will set them all.  Multiple entries may be passed as an option\n"
       "argument list.\n"));
#line 859 "../usage.c"
  puts(_("\t\t\t\t- may appear up to %d times\n"));
#line 52 "../enum.c"
  puts(_("The valid \"%s\" option keywords are:\n"));
#line 1101 "../usage.c"
  puts(_("The next option supports vendor supported extra options:"));
#line 722 "../usage.c"
  puts(_("These additional options are:"));
  /* END-USAGE-TEXT */
}
#endif /* uncompilable code */
#ifdef  __cplusplus
}
#endif
/* ocsptool-args.c ends here */
